==> jc-1.4.0.tar.gz: java/util/logging/SimpleFormatter.h <==
// public class java.util.logging.SimpleFormatter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class afd6918748171c7a java_util_logging_Formatter
// @dep_class a272629b7aeb2aed java_util_logging_SimpleFormatter

// header file dependencies
// @dep_header java_util_logging_Formatter

#include "java/util/logging/Formatter.h"

#ifndef _JC_java_util_logging_SimpleFormatter_H_
#define _JC_java_util_logging_SimpleFormatter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_text_DateFormat$object;
struct _jc_java_util_logging_LogRecord$object;

// Typedefs
typedef struct _jc_java_util_logging_SimpleFormatter$sub_refs	_jc_java_util_logging_SimpleFormatter$sub_refs;
typedef struct _jc_java_util_logging_SimpleFormatter$sub_nonrefs	_jc_java_util_logging_SimpleFormatter$sub_nonrefs;
typedef struct _jc_java_util_logging_SimpleFormatter$refs	_jc_java_util_logging_SimpleFormatter$refs;
typedef struct _jc_java_util_logging_SimpleFormatter$nonrefs	_jc_java_util_logging_SimpleFormatter$nonrefs;
typedef struct _jc_java_util_logging_SimpleFormatter$object	_jc_java_util_logging_SimpleFormatter$object;

typedef struct _jc_java_util_logging_SimpleFormatter$fields_struct	_jc_java_util_logging_SimpleFormatter$fields_struct;
typedef const struct _jc_java_util_logging_SimpleFormatter$vmethods	_jc_java_util_logging_SimpleFormatter$vmethods;
typedef const struct _jc_java_util_logging_SimpleFormatter$vtable	_jc_java_util_logging_SimpleFormatter$vtable;
typedef const struct _jc_java_util_logging_SimpleFormatter$vtype	_jc_java_util_logging_SimpleFormatter$vtype;

// Class fields structure
struct _jc_java_util_logging_SimpleFormatter$fields_struct {
	struct _jc_java_lang_String$object	*lineSep;
};
extern _jc_java_util_logging_SimpleFormatter$fields_struct _jc_java_util_logging_SimpleFormatter$class_fields;

// Constructors
extern void _jc_java_util_logging_SimpleFormatter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_logging_SimpleFormatter$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_util_logging_SimpleFormatter$method$format$8b25c74979926e38(_jc_env *, struct _jc_java_util_logging_SimpleFormatter$object *, struct _jc_java_util_logging_LogRecord$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_logging_SimpleFormatter$method_info$format$8b25c74979926e38;

// Static methods
extern void _jc_java_util_logging_SimpleFormatter$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_util_logging_SimpleFormatter$vmethods {
	struct _jc_java_lang_String$object	*(*format$8b25c74979926e38)(_jc_env *, struct _jc_java_util_logging_SimpleFormatter$object *, struct _jc_java_util_logging_LogRecord$object *);
};

// Vtable
struct _jc_java_util_logging_SimpleFormatter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_logging_Formatter$vmethods	java_util_logging_Formatter;
	_jc_java_util_logging_SimpleFormatter$vmethods	java_util_logging_SimpleFormatter;
};

// Vtype
struct _jc_java_util_logging_SimpleFormatter$vtype {
	_jc_type			type;
	_jc_java_util_logging_SimpleFormatter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_logging_SimpleFormatter$sub_refs {
	struct _jc_java_text_DateFormat$object	*dateFormat;
};

// Reference instance fields (object)
struct _jc_java_util_logging_SimpleFormatter$refs {
    _jc_java_util_logging_SimpleFormatter$sub_refs	java_util_logging_SimpleFormatter;
    _jc_java_util_logging_Formatter$sub_refs	java_util_logging_Formatter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_logging_SimpleFormatter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_logging_SimpleFormatter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_logging_Formatter$sub_nonrefs	java_util_logging_Formatter;
    _jc_java_util_logging_SimpleFormatter$sub_nonrefs	java_util_logging_SimpleFormatter;
};

// Object instance structure
struct _jc_java_util_logging_SimpleFormatter$object {
	_jc_java_util_logging_SimpleFormatter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_logging_SimpleFormatter$vtype	*vtype;
	_jc_java_util_logging_SimpleFormatter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_logging_SimpleFormatter$vtype _jc_java_util_logging_SimpleFormatter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_logging_SimpleFormatter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_logging_SimpleFormatter$class_object;

#endif	/* _JC_java_util_logging_SimpleFormatter_H_ */

==> jc-1.4.6.tar.gz: java/util/logging/SimpleFormatter.h <==
// public class java.util.logging.SimpleFormatter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class afd6918748171c7a java_util_logging_Formatter
// @dep_class a272629b7aeb2aed java_util_logging_SimpleFormatter

// header file dependencies
// @dep_header java_util_logging_Formatter

#include "java/util/logging/Formatter.h"

#ifndef _JC_java_util_logging_SimpleFormatter_H_
#define _JC_java_util_logging_SimpleFormatter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_text_DateFormat$object;
struct _jc_java_util_logging_LogRecord$object;

// Typedefs
typedef struct _jc_java_util_logging_SimpleFormatter$sub_refs	_jc_java_util_logging_SimpleFormatter$sub_refs;
typedef struct _jc_java_util_logging_SimpleFormatter$sub_nonrefs	_jc_java_util_logging_SimpleFormatter$sub_nonrefs;
typedef struct _jc_java_util_logging_SimpleFormatter$refs	_jc_java_util_logging_SimpleFormatter$refs;
typedef struct _jc_java_util_logging_SimpleFormatter$nonrefs	_jc_java_util_logging_SimpleFormatter$nonrefs;
typedef struct _jc_java_util_logging_SimpleFormatter$object	_jc_java_util_logging_SimpleFormatter$object;

typedef struct _jc_java_util_logging_SimpleFormatter$fields_struct	_jc_java_util_logging_SimpleFormatter$fields_struct;
typedef const struct _jc_java_util_logging_SimpleFormatter$vmethods	_jc_java_util_logging_SimpleFormatter$vmethods;
typedef const struct _jc_java_util_logging_SimpleFormatter$vtable	_jc_java_util_logging_SimpleFormatter$vtable;
typedef const struct _jc_java_util_logging_SimpleFormatter$vtype	_jc_java_util_logging_SimpleFormatter$vtype;

// Class fields structure
struct _jc_java_util_logging_SimpleFormatter$fields_struct {
	struct _jc_java_lang_String$object	*lineSep;
};
extern _jc_java_util_logging_SimpleFormatter$fields_struct _jc_java_util_logging_SimpleFormatter$class_fields;

// Constructors
extern void _jc_java_util_logging_SimpleFormatter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_logging_SimpleFormatter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_java_util_logging_SimpleFormatter$method$format$8b25c74979926e38(_jc_env *, struct _jc_java_util_logging_SimpleFormatter$object *, struct _jc_java_util_logging_LogRecord$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_logging_SimpleFormatter$method_info$format$8b25c74979926e38;

// Static methods
extern void _jc_java_util_logging_SimpleFormatter$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_util_logging_SimpleFormatter$vmethods {
	struct _jc_java_lang_String$object	*(*format$8b25c74979926e38)(_jc_env *, struct _jc_java_util_logging_SimpleFormatter$object *, struct _jc_java_util_logging_LogRecord$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_logging_SimpleFormatter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_logging_Formatter$vmethods	java_util_logging_Formatter;
	_jc_java_util_logging_SimpleFormatter$vmethods	java_util_logging_SimpleFormatter;
};

// Vtype
struct _jc_java_util_logging_SimpleFormatter$vtype {
	_jc_type			type;
	_jc_java_util_logging_SimpleFormatter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_logging_SimpleFormatter$sub_refs {
	struct _jc_java_text_DateFormat$object	*dateFormat;
};

// Reference instance fields (object)
struct _jc_java_util_logging_SimpleFormatter$refs {
    _jc_java_util_logging_SimpleFormatter$sub_refs	java_util_logging_SimpleFormatter;
    _jc_java_util_logging_Formatter$sub_refs	java_util_logging_Formatter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_logging_SimpleFormatter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_logging_SimpleFormatter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_logging_Formatter$sub_nonrefs	java_util_logging_Formatter;
    _jc_java_util_logging_SimpleFormatter$sub_nonrefs	java_util_logging_SimpleFormatter;
};

// Object instance structure
struct _jc_java_util_logging_SimpleFormatter$object {
	_jc_java_util_logging_SimpleFormatter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_logging_SimpleFormatter$vtype	*vtype;
	_jc_java_util_logging_SimpleFormatter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_logging_SimpleFormatter$vtype _jc_java_util_logging_SimpleFormatter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_logging_SimpleFormatter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_logging_SimpleFormatter$class_object;

#endif	/* _JC_java_util_logging_SimpleFormatter_H_ */
